==> nextcloud-22.2.9.tgz: nextcloud/apps/federation/l10n/pt_BR.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis.",
    "Server is already in the list of trusted servers." : "O servidor já está na lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor encontrado para federar",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "A federação permite que você se conecte a outros servidores confiáveis para trocar o diretório do usuário.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federação permite que você conecte com outros servidores confiáveis para trocar o diretório do usuário. Por exemplo, este atributo será usado para completar automaticamente usuários externos para compartilhamento federado.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A federação permite que você se conecte com outros servidores confiáveis para trocar o diretório do usuário. Isso é usado, por exemplo, para auto-completar automaticamente usuários externos para compartilhamento federado. Não é necessário adicionar um servidor como servidor confiável para criar um compartilhamento federado.",
    "+ Add trusted server" : "+Adicionar servidores confiáveis",
    "Trusted server" : "Servidores confiáveis",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/federation/l10n/pt_BR.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis.",
    "Server is already in the list of trusted servers." : "O servidor já está na lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor encontrado para federar",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "+ Add trusted server" : "+Adicionar servidores confiáveis",
    "Trusted server" : "Servidores confiáveis",
    "Add" : "Adicionar",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "A federação permite que você se conecte a outros servidores confiáveis para trocar o diretório do usuário.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federação permite que você conecte com outros servidores confiáveis para trocar o diretório do usuário. Por exemplo, este atributo será usado para completar automaticamente usuários externos para compartilhamento federado.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "A federação permite que você se conecte com outros servidores confiáveis para trocar o diretório do usuário. Isso é usado, por exemplo, para auto-completar automaticamente usuários externos para compartilhamento federado. Não é necessário adicionar um servidor como servidor confiável para criar um compartilhamento federado."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
